// Load in the required modules
const Patches = require('Patches');
const Diagnostics = require('Diagnostics');
const Multipeer = require('Multipeer');

(async function () { // Enable async/await in JS [part 1]

  // Initialize background tracking variables
  const totalBackgroundCount = 3;
  var backgroundIndex = 0;

  // Get the tap event from the Patch Editor
  const screenTapPulse = await Patches.outputs.getPulse('screenTapPulse');

 // Create a message channel
 const backgroundIndexChannel = Multipeer.getMessageChannel('BackgroundIndexTopic');

  // Subscribe to the screen tap event
  screenTapPulse.subscribe(() => {

    // Increment the background index to show the next background image
    backgroundIndex++;

    // If the index value is equal to the total number of background images,
    // reset the value so that the displayed image loops.
    if (backgroundIndex >= totalBackgroundCount) {
        backgroundIndex = 0;
    }

    // Send the new background index value to the Patch Editor, so that it can be
    // used to update the background image displayed. This only updates the
    // background for the participant that tapped on the screen
    Patches.inputs.setScalar('msg_background', backgroundIndex);

    // Broadcast the new background index value to other participants on the
    // previously created backgroundIndexChannel message channel
    backgroundIndexChannel.sendMessage({'background': backgroundIndex }, true).catch(err => {

       // If there was an error sending the message, log it to the console
       Diagnostics.log(err);
    });

  });

  // Listen out for messages sent to the backgroundIndexChannel
  backgroundIndexChannel.onMessage.subscribe((msg) => {

    // Retrieve the 'background' attribute from the JSON object received
    backgroundIndex = msg.background;

    // Send the value to the Patch Editor
    Patches.inputs.setScalar('msg_background', msg.background);
  });

})(); // Enable async/await in JS [part 2]
